@@ -18,10 +18,11 @@
 ## Only for stable fetching 
 #############################
 #### stable .tar.gz 
-STABLE_LB=1.5.2
-STABLE_FFLAS=2.3.1
-STABLE_GIVARO=4.0.4
-STABLE_OPENBLAS=0.2.20
+STABLE_LB=1.6.2
+STABLE_FFLAS=2.4.0
+STABLE_GIVARO=4.1.0
+STABLE_OPENBLAS=0.3.6
+STABLE_BLIS=0.5.2
 MD5SUFF=md5
 #############################
 
@@ -53,12 +54,12 @@ EXTRA=""
 EXTRA_VAR=""
 IML="--with-iml"
 IML_VAR=""
-SAGE=""
-SAGE_VAR="false"
 DRIV=""
 DRIV_VAR="false"
 OPENBLAS=""
 OPENBLAS_VAR="false"
+BLIS=""
+BLIS_VAR="false"
 MAKEOPT= 
 MAKE_VAR=""
 
@@ -118,6 +119,8 @@ help() {
     echo
     echo " --enable-openblas     : fetch openblas."
     echo "                         Default : disabled (use local blas)."
+    echo " --enable-blis         : fetch flame/blis."
+    echo "                         Default : disabled (use local blas)."
     echo " --enable-debug        : build in debugging mode."
     echo "                         Default : disabled."
     echo " --enable-check        : run make check."
@@ -126,8 +129,6 @@ help() {
     echo "                         Default : disabled. May be \'full\' "
     echo " --enable-optimization : build with compile-time optimization."
     echo "                         Default : enabled."
-    echo " --enable-sage         : build with sage support."
-    echo "                         Default : disabled."
     echo " --enable-drivers      : build with drivers support."
     echo "                         Default : disabled."
     echo 
@@ -154,7 +155,7 @@ for arg in "$@"
       CMDLINE="$CMDLINE $WHO=\"$WHAT\""
   fi
 done
-echo  "$0 $CMDLINE" | tee -a auto-install.log
+echo  "$0 $CMDLINE" | tee -a linbox-auto-install.log
 
 # Parse command line
 for i in "$@" ; do
@@ -192,6 +193,11 @@ for i in "$@" ; do
 	OPENBLAS="$i";
 	OPENBLAS_VAR="true";
 	;;
+	"--enable-blis")
+	if [ "x$BLIS_VAR" = "xfalse" ]  ; then  echo "enable-blis or not ?" ;        help ; exit -1 ; fi
+	BLIS="$i";
+	BLIS_VAR="true";
+	;;
 	"--disable-debug")
 	if [ "x$DEBUG_VAR" = "xtrue" ]  ; then  echo "enable-debug or not ?" ;        help ; exit -1 ; fi
 	DEBUG_VAR="false";
@@ -212,6 +218,10 @@ for i in "$@" ; do
 	if [ "x$OPENBLAS_VAR" = "xtrue" ]  ; then  echo "enable-openblas or not ?" ;        help ; exit -1 ; fi
 	OPENBLAS_VAR="false";
 	;;
+	"--disable-blis")
+	if [ "x$BLIS_VAR" = "xtrue" ]  ; then  echo "enable-blis or not ?" ;        help ; exit -1 ; fi
+	BLIS_VAR="false";
+	;;
 	"--with-ntl")
 	if	[ "x$NTL_VAR" = "xfalse" ] ; then   echo "with-ntl or not ?";            help ; exit -1; fi
 	NTL="$i";
@@ -227,21 +237,11 @@ for i in "$@" ; do
 	IML="$i "
 	IML_VAR="true"
 	;;
-	"--enable-sage")
-	if	[ "x$SAGE_VAR" = "xfalse" ] ; then  echo "enable-sage or not ?";          help ; exit -1; fi
-	SAGE="$i"
-	SAGE_VAR="true"
-	;;
 	"--enable-drivers")
 	if	[ "x$DRIV_VAR" = "xfalse" ] ; then  echo "enable-drivers or not ?" ;      help ; exit -1; fi
 	DRIV="$i"
 	DRIV_VAR="true"
 	;;
-	"--disable-sage")
-	if	[ "x$SAGE_VAR" = "xtrue" ] ; then  echo "enable-sage or not ?";          help ; exit -1; fi
-	SAGE=""
-	SAGE_VAR="false"
-	;;
 	"--disable-drivers")
 	if	[ "x$DRIV_VAR" = "xtrue" ] ; then  echo "enable-drivers or not ?" ;      help ; exit -1; fi
 	DRIV=""
@@ -308,7 +308,7 @@ for i in "$@" ; do
 	    [[ "$QUOI" =~ y|yes|Y|1 ]] && OK=1 || OK=0
 	    if		[ "x$OPTIM_VAR" = "xtrue"  -a "OK" = "0" ] ; then  echo "optim or not optim ?" ;      help ; exit -1; fi
 	    if		[ "x$OPTIM_VAR" = "xfalse" -a "OK" = "1" ] ; then  echo "optim or not optim ?" ;      help ; exit -1; fi
-	    if	[[ "x$OK" = "x1" ]] ; then  
+	    if	[[ "x$OK" = "x1" ]] ; then
 		OPTIM=$QUI ; OPTIM_VAR="true" ;
 	    else
 		OPTIM_VAR="false" ;
@@ -324,6 +324,16 @@ for i in "$@" ; do
 		OPENBLAS_VAR="false" ;
 	    fi
 	    ;;
+	    "--enable-blis")
+	    [[ "$QUOI" =~ y|yes|Y|1 ]] && OK=1 || OK=0
+	    if		[ "x$BLIS_VAR" = "xtrue"  -a "OK" = "0" ] ; then  echo "blis or not blis ?" ;      help ; exit -1; fi
+	    if		[ "x$BLIS_VAR" = "xfalse" -a "OK" = "1" ] ; then  echo "blis or not blis ?" ;      help ; exit -1; fi
+	    if	[[ "x$OK" = "x1" ]] ; then
+		BLIS=$QUI ; BLIS_VAR="true" ;
+	    else
+		BLIS_VAR="false" ;
+	    fi
+	    ;;
 	    "--enable-warnings")
 	    [[ "$QUOI" =~ y|yes|Y|1|full ]] && OK=1 || OK=0
 	    if [ "x$WARNING_VAR" = "xtrue"  -a "OK" = "0"  ] ; then  echo "warning or not warning ?" ;      help ; exit -1; fi
@@ -355,16 +365,6 @@ for i in "$@" ; do
 		CHECK_VAR="false"
 	    fi
 	    ;;
-	    "--enable-sage")
-	    [[ "$QUOI" =~ y|yes|Y|1 ]] && OK=1 || OK=0
-	    if		[ "x$SAGE_VAR" = "xtrue"  -a "OK" = "0"  ] ; then  echo "sage or not sage ?" ;      help ; exit -1; fi
-	    if		[ "x$SAGE_VAR" = "xfalse" -a "OK" = "1"  ] ; then  echo "sage or not sage ?" ;      help ; exit -1; fi
-	    if		[[ "x$OK" = "x1" ]] ; then 
-		SAGE=$QUI ; SAGE_VAR="true" 
-	    else
-		SAGE_VAR="false" 
-	    fi
-	    ;;
 	    "--enable-drivers")
 	    [[ "$QUOI" =~ y|yes|Y|1 ]] && OK=1 || OK=0
 	    if		[ "x$OPTIM_VAR" = "xtrue"  -a "OK" = "0"  ] ; then  echo "drivers or not drivers ?" ;      help ; exit -1; fi
@@ -387,9 +387,9 @@ done
 
 MAKEPROG="make ${MAKEOPT}"
 export PKG_CONFIG_PATH=${PKG_CONFIG_PATH}:${PREFIX_LOC}/lib/pkgconfig
-echo "PKG_CONFIG_PATH=$PKG_CONFIG_PATH"| tee -a auto-install.log
+echo "PKG_CONFIG_PATH=$PKG_CONFIG_PATH"| tee -a linbox-auto-install.log
 export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:$PREFIX_LOC/lib
-echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"| tee -a auto-install.log
+echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"| tee -a linbox-auto-install.log
 
 
 
@@ -400,38 +400,38 @@ echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"| tee -a auto-install.log
 if [ ! \( -x autogen.sh -o -x configure \) ] ; then
 
 ### Extract LinBox sources ###
-    echo -en "${BEG}fetching LinBox..."| tee -a auto-install.log
+    echo -en "${BEG}fetching LinBox..."| tee -a linbox-auto-install.log
     if [ "$STABLE_VAR" = "true" ]; then
 	if [ -f linbox-${STABLE_LB}.tar.gz ] ; then
-	    echo -ne " already there!\n"| tee -a auto-install.log
-	    echo -ne "${BEG}fetching md5sum" | tee -a auto-install.log;
-	    [ -f fflas-ffpack-${STABLE_FFLAS}.tar.gz.${MD5SUFF} ] && rm fflas-ffpack-${STABLE_FFLAS}.tar.gz.${MD5SUFF} ;
+	    echo -ne " already there!\n"| tee -a linbox-auto-install.log
+	    echo -ne "${BEG}fetching md5sum" | tee -a linbox-auto-install.log;
+	    [ -f linbox-${STABLE_FFLAS}.tar.gz.${MD5SUFF} ] && rm linbox-${STABLE_FFLAS}.tar.gz.${MD5SUFF} ;
 	    wget --no-check-certificate https://github.com/linbox-team/linbox/releases/download/v${STABLE_LB}/linbox-${STABLE_LB}.tar.gz.${MD5SUFF} >/dev/null 2>&1 || die
 	    [ -f linbox-${STABLE_LB}.tar.gz.${MD5SUFF} ] || die
-	    cool| tee -a auto-install.log
+	    cool| tee -a linbox-auto-install.log
 	    echo -ne "${BEG}"
 	    md5sum -c linbox-${STABLE_LB}.tar.gz.${MD5SUFF} || die
 	else
 	    wget https://github.com/linbox-team/linbox/releases/download/v${STABLE_LB}/linbox-${STABLE_LB}.tar.gz >/dev/null 2>&1 || die
 	    [ -f linbox-${STABLE_LB}.tar.gz ] &&  cool || die
-	    echo -ne "${BEG}fetching md5sum" | tee -a auto-install.log; 
+	    echo -ne "${BEG}fetching md5sum" | tee -a linbox-auto-install.log; 
 	    wget --no-check-certificate https://github.com/linbox-team/linbox/releases/download/v${STABLE_LB}/linbox-${STABLE_LB}.tar.gz.${MD5SUFF} >/dev/null 2>&1 || die
-	    cool| tee -a auto-install.log
+	    cool| tee -a linbox-auto-install.log
 	    echo -ne "${BEG}"
 	    md5sum -c linbox-${STABLE_LB}.tar.gz.${MD5SUFF} || die
 	fi
 	OK=0
 	echo -en "${BEG}extracting LinBox..."
 	decompress linbox-${STABLE_LB}.tar.gz  && OK=1
-	[ "$OK" = "1" ] &&  cool | tee -a auto-install.log  || die 
+	[ "$OK" = "1" ] &&  cool | tee -a linbox-auto-install.log  || die 
 	cd linbox-${STABLE_LB} &&  cool   || die 
     else
 	OK=0 ;
 	git clone --depth 1 https://github.com/linbox-team/linbox.git 2>&1 >/dev/null && OK=1
-	[ "$OK" = "1" ] &&  cool | tee -a auto-install.log || die
+	[ "$OK" = "1" ] &&  cool | tee -a linbox-auto-install.log || die
 	cd linbox &&  cool   || die 
     fi
-    mv ../auto-install.log . || die
+    mv ../linbox-auto-install.log . || die
 fi
 
 ######################
@@ -439,7 +439,7 @@ fi
 ######################
 
 #first tee creates a new log.
-echo -en "${BEG}Preparing build directory..."| tee -a auto-install.log
+echo -en "${BEG}Preparing build directory..."| tee -a linbox-auto-install.log
 if [ -e build ] ; then
     if [ ! -d build ] ; then
 	rm -rf build ;
@@ -452,7 +452,7 @@ else
 	# echo -n "creating empty build directory..."
     mkdir build
 fi
-cool| tee -a auto-install.log
+cool| tee -a linbox-auto-install.log
 
 ####################
 #  fetch sources  #
@@ -462,7 +462,7 @@ cd build ;
 
 ### Givaro ###
 
-echo -en "${BEG}fetching Givaro..."| tee -a ../auto-install.log
+echo -en "${BEG}fetching Givaro..."| tee -a ../linbox-auto-install.log
 if [ "$STABLE_VAR" = "true" ]; then
     if [ -f givaro-${STABLE_GIVARO}.tar.gz ] ; then
 	echo -ne " already there!\n"
@@ -470,7 +470,7 @@ if [ "$STABLE_VAR" = "true" ]; then
 	[ -f givaro-${STABLE_GIVARO}.tar.gz.${MD5SUFF} ] && rm givaro-${STABLE_GIVARO}.tar.gz.${MD5SUFF} ;
 	wget --no-check-certificate https://github.com/linbox-team/givaro/releases/download/v${STABLE_GIVARO}/givaro-${STABLE_GIVARO}.tar.gz.${MD5SUFF} >/dev/null 2>&1 || die
 	[ -f givaro-${STABLE_GIVARO}.tar.gz.${MD5SUFF} ] || die
-	cool| tee -a ../auto-install.log
+	cool| tee -a ../linbox-auto-install.log
 	echo -ne "${BEG}"
 	md5sum -c givaro-${STABLE_GIVARO}.tar.gz.${MD5SUFF} || die
     else
@@ -478,19 +478,19 @@ if [ "$STABLE_VAR" = "true" ]; then
 	[ -f givaro-${STABLE_GIVARO}.tar.gz ] &&  cool || die
 	echo -ne "${BEG}fetching md5sum" ; 
 	wget --no-check-certificate https://github.com/linbox-team/givaro/releases/download/v${STABLE_GIVARO}/givaro-${STABLE_GIVARO}.tar.gz.${MD5SUFF} >/dev/null 2>&1 || die
-	cool| tee -a ../auto-install.log
+	cool| tee -a ../linbox-auto-install.log
 	echo -ne "${BEG}"
 	md5sum -c givaro-${STABLE_GIVARO}.tar.gz.${MD5SUFF} || die
     fi
 else
     OK=0 ;
     git clone --depth 1 https://github.com/linbox-team/givaro.git 2>&1 >/dev/null && OK=1
-    [ "$OK" = "1" ] &&  cool | tee -a ../auto-install.log || die 
+    [ "$OK" = "1" ] &&  cool | tee -a ../linbox-auto-install.log || die 
 fi
 
 ### Fflas-ffpack ###
 
-echo -en "${BEG}fetching Fflas-Ffpack..."| tee -a ../auto-install.log
+echo -en "${BEG}fetching Fflas-Ffpack..."| tee -a ../linbox-auto-install.log
 if [ "$STABLE_VAR" = "true" ]; then
     if [ -f fflas-ffpack-${STABLE_FFLAS}.tar.gz ] ; then
 	echo -ne " already there!\n"
@@ -513,13 +513,13 @@ if [ "$STABLE_VAR" = "true" ]; then
 else
     OK=0 ;
     git clone --depth=1 https://github.com/linbox-team/fflas-ffpack.git 2>&1 >/dev/null && OK=1
-    [ "$OK" = "1" ] &&  cool | tee -a ../auto-install.log || die
+    [ "$OK" = "1" ] &&  cool | tee -a ../linbox-auto-install.log || die
 fi
 
 
 ### OpenBlas ###
 if [ "$OPENBLAS_VAR" = "true" ]; then
-    echo -en "${BEG}fetching OpenBlas..."| tee -a ../auto-install.log
+    echo -en "${BEG}fetching OpenBlas..."| tee -a ../linbox-auto-install.log
     if [ "$STABLE_VAR" = "true" ]; then
 	if [ -f v${STABLE_OPENBLAS}.tar.gz ] ; then
 	    echo -ne " already there!\n"
@@ -530,7 +530,24 @@ if [ "$OPENBLAS_VAR" = "true" ]; then
     else
 	OK=0 ;
 	git clone --depth=1 https://github.com/xianyi/OpenBLAS.git 2>&1 >/dev/null && OK=1
-	[ "$OK" = "1" ] &&  cool | tee -a ../auto-install.log || die
+	[ "$OK" = "1" ] &&  cool | tee -a ../linbox-auto-install.log || die
+    fi
+fi
+
+### flame/blis ###
+if [ "$BLIS_VAR" = "true" ]; then
+    echo -en "${BEG}fetching FLAME/Blis..."| tee -a ../linbox-auto-install.log
+    if [ "$STABLE_VAR" = "true" ]; then
+	if [ -f ${STABLE_BLIS}.tar.gz ] ; then
+	    echo -ne " already there!\n"
+	else
+	    wget --no-check-certificate https://github.com/flame/blis/archive/${STABLE_BLIS}.tar.gz >/dev/null 2>&1 || die
+	    [ -f ${STABLE_BLIS}.tar.gz ] &&  cool || die
+	fi
+    else
+	OK=0 ;
+	git clone --depth=1 https://github.com/flame/blis.git 2>&1 >/dev/null && OK=1
+	[ "$OK" = "1" ] &&  cool | tee -a ../linbox-auto-install.log || die
     fi
 fi
 
@@ -542,18 +559,18 @@ fi
 
 OK=0
 if [ "$STABLE_VAR" = "true" ]; then
-    echo -en "${BEG}extracting Givaro..."| tee -a ../auto-install.log
+    echo -en "${BEG}extracting Givaro..."| tee -a ../linbox-auto-install.log
     decompress givaro-${STABLE_GIVARO}.tar.gz  && OK=1
-    [ "$OK" = "1" ] &&  cool | tee -a ../auto-install.log  || die 
+    [ "$OK" = "1" ] &&  cool | tee -a ../linbox-auto-install.log  || die 
 fi
 
 ### Fflas-ffpack ###
 
 OK=0
 if [ "$STABLE_VAR" = "true" ]; then
-    echo -en "${BEG}extracting Fflas-Ffpack..."| tee -a ../auto-install.log
+    echo -en "${BEG}extracting Fflas-Ffpack..."| tee -a ../linbox-auto-install.log
     decompress fflas-ffpack-${STABLE_FFLAS}.tar.gz  && OK=1
-    [ "$OK" = "1" ] &&  cool  | tee -a ../auto-install.log || die
+    [ "$OK" = "1" ] &&  cool  | tee -a ../linbox-auto-install.log || die
 fi
 
 ### OpenBlas ###
@@ -561,9 +578,20 @@ fi
 if [ "$OPENBLAS_VAR" = "true" ]; then
     OK=0
     if [ "$STABLE_VAR" = "true" ]; then
-	echo -en "${BEG}extracting OpenBlas..."| tee -a ../auto-install.log
+	echo -en "${BEG}extracting OpenBlas..."| tee -a ../linbox-auto-install.log
 	decompress v${STABLE_OPENBLAS}.tar.gz  && OK=1
-	[ "$OK" = "1" ] &&  cool | tee -a ../auto-install.log  || die
+	[ "$OK" = "1" ] &&  cool | tee -a ../linbox-auto-install.log  || die
+    fi
+fi
+
+### BLIS ###
+
+if [ "$BLIS_VAR" = "true" ]; then
+    OK=0
+    if [ "$STABLE_VAR" = "true" ]; then
+	echo -en "${BEG}extracting Blis..."| tee -a ../linbox-auto-install.log
+	decompress ${STABLE_BLIS}.tar.gz  && OK=1
+	[ "$OK" = "1" ] &&  cool | tee -a ../linbox-auto-install.log  || die
     fi
 fi
 
@@ -578,9 +606,9 @@ else
 fi
 
 if [ -f Makefile ] ; then
-    echo -e "${BEG}cleaning Givaro..."| tee -a ../../auto-install.log
-    ${MAKEPROG} clean | tee -a ../../auto-install.log|| die
-    ${MAKEPROG} distclean | tee -a ../../auto-install.log|| die 
+    echo -e "${BEG}cleaning Givaro..."| tee -a ../../linbox-auto-install.log
+    ${MAKEPROG} clean | tee -a ../../linbox-auto-install.log|| die
+    ${MAKEPROG} distclean | tee -a ../../linbox-auto-install.log|| die 
 	# ${MAKEPROG} unistall || die
     cool
 fi
@@ -591,39 +619,39 @@ if [ "$STABLE_VAR" = "true" ]; then
     echo "./configure  $PREFIX $DEBUG $OPTIM $GMP $WARNINGS "
     echo "./configure  $PREFIX $DEBUG $OPTIM $GMP $WARNINGS " > configure.givaro.exe
     chmod +x configure.givaro.exe
-    ./configure.givaro.exe | tee -a ../../auto-install.log
+    ./configure.givaro.exe | tee -a ../../linbox-auto-install.log
     rm -rf configure.givaro.exe
 	#./configure  $PREFIX $DEBUG $OPTIM $GMP $WARNINGS || die
 else
     echo "./autogen.sh $PREFIX $DEBUG $OPTIM $GMP $WARNINGS"
     echo "./autogen.sh $PREFIX $DEBUG $OPTIM $GMP $WARNINGS" > autogen.givaro.exe
     chmod +x autogen.givaro.exe
-    ./autogen.givaro.exe| tee -a ../../auto-install.log
+    ./autogen.givaro.exe| tee -a ../../linbox-auto-install.log
     rm -rf autogen.givaro.exe
 	#./autogen.sh $PREFIX $DEBUG $OPTIM $GMP $WARNINGS || die
 fi
 
-echo -e "${BEG}building Givaro..."| tee -a ../../auto-install.log
-echo "${MAKEPROG} CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ../../auto-install.log
+echo -e "${BEG}building Givaro..."| tee -a ../../linbox-auto-install.log
+echo "${MAKEPROG} CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ../../linbox-auto-install.log
 
 if [ -n "$EXTRA" ] ; then
-    ${MAKEPROG} "CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\"" | tee -a ../../auto-install.log|| die
+    ${MAKEPROG} "CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\"" | tee -a ../../linbox-auto-install.log|| die
 else
-    ${MAKEPROG} | tee -a ../../auto-install.log|| die
+    ${MAKEPROG} | tee -a ../../linbox-auto-install.log|| die
 fi
 
 if [ "$CHECK_VAR" = "true" ] ; then
-    echo -e "${BEG}checking Fflas-Ffpack..."| tee -a ../../auto-install.log
-    ${MAKEPROG} check | tee -a ../../auto-install.log|| die
+    echo -e "${BEG}checking Fflas-Ffpack..."| tee -a ../../linbox-auto-install.log
+    ${MAKEPROG} check | tee -a ../../linbox-auto-install.log|| die
 fi
 
-echo -e "${BEG}installing Givaro..."| tee -a ../../auto-install.log
-${MAKEPROG} install | tee -a ../../auto-install.log|| die
+echo -e "${BEG}installing Givaro..."| tee -a ../../linbox-auto-install.log
+${MAKEPROG} install | tee -a ../../linbox-auto-install.log|| die
 
 #return in build
 cd ..
 
-cool| tee -a ../auto-install.log
+cool| tee -a ../linbox-auto-install.log
 
 ######################
 #  install OpenBlas  #
@@ -638,31 +666,31 @@ if [ "$OPENBLAS_VAR" = "true" ]; then
     fi
     
     if [ -f Makefile ] ; then
-	echo -e "${BEG}cleaning OpenBLAS..."| tee -a ../../auto-install.log
-	${MAKEPROG} clean | tee -a ../../auto-install.log|| die
-	${MAKEPROG} distclean | tee -a ../../auto-install.log|| die 
+	echo -e "${BEG}cleaning OpenBLAS..."| tee -a ../../linbox-auto-install.log
+	${MAKEPROG} clean | tee -a ../../linbox-auto-install.log|| die
+	${MAKEPROG} distclean | tee -a ../../linbox-auto-install.log|| die 
 	# ${MAKEPROG} unistall || die
 	cool
     fi
     
     OPENBLAS_FLAGS="USE_THREADS=0 USE_THREAD=0 CC=gcc FC=gfortran PREFIX=$PREFIX_LOC"
     
-    echo -e "${BEG}building OpenBLAS..."| tee -a ../../auto-install.log
-    echo "${MAKEPROG} ${OPENBLAS_FLAGS} CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ../../auto-install.log
+    echo -e "${BEG}building OpenBLAS..."| tee -a ../../linbox-auto-install.log
+    echo "${MAKEPROG} ${OPENBLAS_FLAGS} CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ../../linbox-auto-install.log
     
     if [ -n "$EXTRA" ] ; then
-	${MAKEPROG} ${OPENBLAS_FLAGS} "CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\"" | tee -a ../../auto-install.log|| die
+	${MAKEPROG} ${OPENBLAS_FLAGS} "CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\"" | tee -a ../../linbox-auto-install.log|| die
     else
-	${MAKEPROG} ${OPENBLAS_FLAGS} | tee -a ../../auto-install.log|| die
+	${MAKEPROG} ${OPENBLAS_FLAGS} | tee -a ../../linbox-auto-install.log|| die
     fi
     
-    echo -e "${BEG}installing OpenBLAS..."| tee -a ../../auto-install.log
-    ${MAKEPROG} ${OPENBLAS_FLAGS} install | tee -a ../../auto-install.log|| die
+    echo -e "${BEG}installing OpenBLAS..."| tee -a ../../linbox-auto-install.log
+    ${MAKEPROG} ${OPENBLAS_FLAGS} install | tee -a ../../linbox-auto-install.log|| die
     
 #return in build
     cd ..
     
-    cool| tee -a ../auto-install.log
+    cool| tee -a ../linbox-auto-install.log
 
     if [ "$BLAS_VAR" = "false" ]; then
 	BLAS="--with-blas-libs="\""-L${PREFIX_LOC}/lib -lopenblas -lpthread -lgfortran"\"
@@ -671,6 +699,59 @@ if [ "$OPENBLAS_VAR" = "true" ]; then
 fi
 
 
+######################
+#  install Blis      #
+######################
+
+if [ "$BLIS_VAR" = "true" ]; then
+
+    if [ "$STABLE_VAR" = "true" ]; then
+	cd blis-${STABLE_BLIS} || die
+    else
+	cd blis/ || die
+    fi
+
+    if [ -f Makefile ] ; then
+	echo -e "${BEG}cleaning Blis..."| tee -a ../../linbox-auto-install.log
+	${MAKEPROG} clean | tee -a ../../linbox-auto-install.log|| die
+	${MAKEPROG} distclean | tee -a ../../linbox-auto-install.log|| die
+	# ${MAKEPROG} unistall || die
+	cool
+    fi
+
+    echo -e "${BEG}configuring Blis..."
+
+    echo "./configure  $PREFIX $DEBUG $WARNINGS --enable-cblas auto"
+    echo "./configure  $PREFIX $DEBUG $WARNINGS --enable-cblas auto " > configure.blis.exe
+    chmod +x configure.blis.exe
+    ./configure.blis.exe | tee -a ../../linbox-auto-install.log
+    rm -rf configure.blis.exe
+
+    echo -e "${BEG}building Blis..."| tee -a ../../linbox-auto-install.log
+    BLIS_FLAGS=""
+
+    echo "${MAKEPROG} ${BLIS_FLAGS} CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ../../linbox-auto-install.log
+    if [ -n "$EXTRA" ] ; then
+	${MAKEPROG} ${BLIS_FLAGS} "CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\"" | tee -a ../../linbox-auto-install.log|| die
+    else
+	${MAKEPROG} ${BLIS_FLAGS} | tee -a ../../linbox-auto-install.log|| die
+    fi
+
+    echo -e "${BEG}installing Blis..."| tee -a ../../linbox-auto-install.log
+    ${MAKEPROG} ${BLIS_FLAGS} install | tee -a ../../linbox-auto-install.log|| die
+
+#return in build
+    cd ..
+
+    cool| tee -a ../linbox-auto-install.log
+
+    if [ "$BLAS_VAR" = "false" ]; then
+	BLAS="--with-blas-libs="\""-L${PREFIX_LOC}/lib -lblis -lpthread"\"
+	BLAS_VAR=true
+    fi
+fi
+
+
 ##########################
 #  install fflas-ffpack  #
 ##########################
@@ -683,49 +764,49 @@ fi
 
 
 if [ -f Makefile ] ; then
-    echo -e "${BEG}cleaning Fflas-Ffpack..."| tee -a ../../auto-install.log
-    ${MAKEPROG} clean | tee -a ../../auto-install.log|| die
-    ${MAKEPROG} distclean | tee -a ../../auto-install.log|| die 
+    echo -e "${BEG}cleaning Fflas-Ffpack..."| tee -a ../../linbox-auto-install.log
+    ${MAKEPROG} clean | tee -a ../../linbox-auto-install.log|| die
+    ${MAKEPROG} distclean | tee -a ../../linbox-auto-install.log|| die 
 	# ${MAKEPROG} unistall || die
-    cool| tee -a ../../auto-install.log
+    cool| tee -a ../../linbox-auto-install.log
 fi
 
-echo -e "${BEG}configuring Fflas-Ffpack..."| tee -a ../../auto-install.log
+echo -e "${BEG}configuring Fflas-Ffpack..."| tee -a ../../linbox-auto-install.log
 
 if [ "$STABLE_VAR" = "true" ]; then
-    echo "./configure  $PREFIX $DEBUG $OPTIM $BLAS $WARNINGS"| tee -a ../../auto-install.log
+    echo "./configure  $PREFIX $DEBUG $OPTIM $BLAS $WARNINGS"| tee -a ../../linbox-auto-install.log
     echo "./configure  $PREFIX $DEBUG $OPTIM $BLAS $WARNINGS" > configure.fflas.exe
     chmod +x configure.fflas.exe
-    ./configure.fflas.exe| tee -a ../../auto-install.log
+    ./configure.fflas.exe| tee -a ../../linbox-auto-install.log
     rm -rf configure.fflas.exe
 	#./configure  "$PREFIX" "$DEBUG" "$OPTIM" "$BLAS"  "$WARNINGS" || die
 else
-    echo "./autogen.sh $PREFIX $DEBUG $OPTIM $BLAS $WARNINGS"| tee -a ../../auto-install.log
+    echo "./autogen.sh $PREFIX $DEBUG $OPTIM $BLAS $WARNINGS"| tee -a ../../linbox-auto-install.log
     echo "./autogen.sh $PREFIX $DEBUG $OPTIM $BLAS $WARNINGS" > configure.fflas.exe
     chmod +x configure.fflas.exe
-    ./configure.fflas.exe| tee -a ../../auto-install.log
+    ./configure.fflas.exe| tee -a ../../linbox-auto-install.log
     rm -rf configure.fflas.exe
 	#./autogen.sh "$PREFIX" "$DEBUG" "$OPTIM" "$BLAS"  "$WARNINGS" || die
 fi
 
-echo -e "${BEG}building Fflas-Ffpack..."| tee -a ../../auto-install.log
+echo -e "${BEG}building Fflas-Ffpack..."| tee -a ../../linbox-auto-install.log
 echo "${MAKEPROG} CXXFLAGS+=\"$EXTRA\""
 if [ -n "$EXTRA" ] ; then
-    ${MAKEPROG} "CXXFLAGS+=\"$EXTRA\"" | tee -a ../../auto-install.log|| die
+    ${MAKEPROG} "CXXFLAGS+=\"$EXTRA\"" | tee -a ../../linbox-auto-install.log|| die
 else
-    ${MAKEPROG} | tee -a ../../auto-install.log|| die
+    ${MAKEPROG} | tee -a ../../linbox-auto-install.log|| die
 fi
 
 if [ "$CHECK_VAR" = "true" ] ; then
-    echo -e "${BEG}checking Fflas-Ffpack..."| tee -a ../../auto-install.log
-    ${MAKEPROG} check | tee -a ../../auto-install.log|| die
+    echo -e "${BEG}checking Fflas-Ffpack..."| tee -a ../../linbox-auto-install.log
+    ${MAKEPROG} check | tee -a ../../linbox-auto-install.log|| die
 fi
 
 
 echo -e "${BEG}installing Fflas-Ffpack..."
-${MAKEPROG} install | tee -a ../../auto-install.log|| die
+${MAKEPROG} install | tee -a ../../linbox-auto-install.log|| die
 
-cool| tee -a ../../auto-install.log
+cool| tee -a ../../linbox-auto-install.log
 #return in build
 cd ..
 
@@ -738,54 +819,54 @@ cd ..
 #####################
 
 if [ -f Makefile ] ; then
-    echo -e "${BEG}cleaning LinBox..."| tee -a ./auto-install.log
-    ${MAKEPROG} clean | tee -a ./auto-install.log|| die
-    ${MAKEPROG} distclean | tee -a ./auto-install.log|| die 
+    echo -e "${BEG}cleaning LinBox..."| tee -a ./linbox-auto-install.log
+    ${MAKEPROG} clean | tee -a ./linbox-auto-install.log|| die
+    ${MAKEPROG} distclean | tee -a ./linbox-auto-install.log|| die 
 	# ${MAKEPROG} unistall || die
-    cool| tee -a ./auto-install.log
+    cool| tee -a ./linbox-auto-install.log
 fi
 
-echo -e "${BEG}configuring LinBox..."| tee -a ./auto-install.log
+echo -e "${BEG}configuring LinBox..."| tee -a ./linbox-auto-install.log
 
-echo ""| tee -a ./auto-install.log
-echo -e "${BEG}Don't forget to run something like"| tee -a ./auto-install.log
-echo -e " *   'export LD_LIBRARY_PATH=\$LD_LIBRARY_PATH:$PREFIX_LOC/lib'"| tee -a ./auto-install.log
-echo -e " * to ensure you don't get undefined symbols !"| tee -a ./auto-install.log
-echo  ""| tee -a ./auto-install.log
+echo ""| tee -a ./linbox-auto-install.log
+echo -e "${BEG}Don't forget to run something like"| tee -a ./linbox-auto-install.log
+echo -e " *   'export LD_LIBRARY_PATH=\$LD_LIBRARY_PATH:$PREFIX_LOC/lib'"| tee -a ./linbox-auto-install.log
+echo -e " * to ensure you don't get undefined symbols !"| tee -a ./linbox-auto-install.log
+echo  ""| tee -a ./linbox-auto-install.log
 
 if [ -x autogen.sh ] ;  then 
-    echo "./autogen.sh $PREFIX $DEBUG $OPTIM $GMP $BLAS $NTL $WARNINGS $IML $SAGE $DRIV"| tee -a ./auto-install.log
-    ./autogen.sh "$PREFIX" "$DEBUG" "$OPTIM" "$GMP" "$BLAS" "$NTL" "$WARNINGS" "$IML" "$SAGE" "$DRIV" | tee -a ./auto-install.log|| die
+    echo "./autogen.sh $PREFIX $DEBUG $OPTIM $GMP $BLAS $NTL $WARNINGS $IML $DRIV"| tee -a ./linbox-auto-install.log
+    ./autogen.sh "$PREFIX" "$DEBUG" "$OPTIM" "$GMP" "$BLAS" "$NTL" "$WARNINGS" "$IML" "$DRIV" | tee -a ./linbox-auto-install.log|| die
 else
-    echo "./configure $PREFIX $DEBUG $OPTIM $GMP $BLAS $NTL $WARNINGS $IML $SAGE $DRIV"| tee -a ./auto-install.log
-	# ./configure $PREFIX $DEBUG $OPTIM $GMP $BLAS $NTL $WARNINGS  $IML $SAGE $DRIV || die
-    ./configure "$PREFIX" "$DEBUG" "$OPTIM" "$GMP" "$BLAS" "$NTL" "$WARNINGS" "$IML" "$SAGE" "$DRIV" | tee -a ./auto-install.log|| die
+    echo "./configure $PREFIX $DEBUG $OPTIM $GMP $BLAS $NTL $WARNINGS $IML $DRIV"| tee -a ./linbox-auto-install.log
+	# ./configure $PREFIX $DEBUG $OPTIM $GMP $BLAS $NTL $WARNINGS  $IML $DRIV || die
+    ./configure "$PREFIX" "$DEBUG" "$OPTIM" "$GMP" "$BLAS" "$NTL" "$WARNINGS" "$IML" "$DRIV" | tee -a ./linbox-auto-install.log|| die
 fi
 
-echo -e "${BEG}building LinBox..."| tee -a ./auto-install.log
-echo "${MAKEPROG} CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ./auto-install.log
+echo -e "${BEG}building LinBox..."| tee -a ./linbox-auto-install.log
+echo "${MAKEPROG} CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ./linbox-auto-install.log
 
 if [ -n "$EXTRA" ] ; then
-    ${MAKEPROG} "CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\"" | tee -a ./auto-install.log|| die
+    ${MAKEPROG} "CXXFLAGS+=\"$EXTRA\" LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\"" | tee -a ./linbox-auto-install.log|| die
 else
-    ${MAKEPROG} "LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ./auto-install.log|| die
+    ${MAKEPROG} "LDFLAGS+=\"-Wl,-rpath,$PREFIX_LOC\""| tee -a ./linbox-auto-install.log|| die
 fi
 
 if [ "$CHECK_VAR" = "true" ] ; then
-    echo -e "${BEG}checking LinBox..."| tee -a auto-install.log
-    ${MAKEPROG} check | tee -a auto-install.log|| die
+    echo -e "${BEG}checking LinBox..."| tee -a linbox-auto-install.log
+    ${MAKEPROG} check | tee -a linbox-auto-install.log|| die
 fi
 
-echo -e "${BEG}installing LinBox..."| tee -a auto-install.log
-${MAKEPROG} install | tee -a auto-install.log|| die
+echo -e "${BEG}installing LinBox..."| tee -a linbox-auto-install.log
+${MAKEPROG} install | tee -a linbox-auto-install.log|| die
 
-cool| tee -a auto-install.log
+cool| tee -a linbox-auto-install.log
 
-echo    " " | tee -a auto-install.log
-echo -e "${BEG}Don't forget to run something like"| tee -a auto-install.log
-echo -e " *   'export LD_LIBRARY_PATH=\$LD_LIBRARY_PATH:$PREFIX_LOC/lib'"| tee -a auto-install.log
-echo -e " * to ensure you don't get undefined symbols !"| tee -a auto-install.log
-echo  "" | tee -a auto-install.log
-echo -e " * Happy LinBoxing ! (installed in $PREFIX_LOC)"| tee -a auto-install.log
-echo " "| tee -a auto-install.log
-cool| tee -a auto-install.log
+echo    " " | tee -a linbox-auto-install.log
+echo -e "${BEG}Don't forget to run something like"| tee -a linbox-auto-install.log
+echo -e " *   'export LD_LIBRARY_PATH=\$LD_LIBRARY_PATH:$PREFIX_LOC/lib'"| tee -a linbox-auto-install.log
+echo -e " * to ensure you don't get undefined symbols !"| tee -a linbox-auto-install.log
+echo  "" | tee -a linbox-auto-install.log
+echo -e " * Happy LinBoxing ! (installed in $PREFIX_LOC)"| tee -a linbox-auto-install.log
+echo " "| tee -a linbox-auto-install.log
+cool| tee -a linbox-auto-install.log
